@@ -1,5 +1,5 @@
 package Dancer2::Plugin::MarkdownFilesToHTML ;
-$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.013';
+$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.014';
 use 5.010; use strict; use warnings;
 
 use Carp;
@@ -169,6 +169,7 @@ sub mdfiles_2html {
 sub mdfile_2html {
 	my ($s, $file, $options) = @_;
 
+  my ($base)   = fileparse($file, qr/\.[^.]*/);
   # If options haven't been set yet, get defaults from cnofig file
   if (!$options->{set}) {
     ($options, $file) = $s->_get_options($options, $file);
@@ -181,12 +182,11 @@ sub mdfile_2html {
   }
 
   # generate unique cache file name appended with values of two options
-  my $cache_file = $file;
-  $cache_file =~ s/\///g;
-  $cache_file = File::Spec->catfile(
-                 $cache_dir,
-                 File::Spec->catfile(dirname($cache_file), basename($cache_file))
-                     . $options->{linkable_headers} . $options->{generate_toc});
+  my $cache_file = dirname($file);
+  my $sep = File::Spec->catfile('', '');
+  $cache_file =~ s/\Q$sep\E//g;
+  $cache_file = File::Spec->catfile($cache_dir,
+                 $cache_file . $base . $options->{linkable_headers} . $options->{generate_toc});
 
   # check for cache hit
   if (-f $cache_file && $options->{cache}) {
@@ -218,7 +218,6 @@ sub mdfile_2html {
 
   my @elements = $tree->look_down(_tag => qr/^h\d$/);
   my $toc      = HTML::TreeBuilder->new();
-  my ($base)   = fileparse($file, qr/\.[^.]*/);
   my $hdr_ct   = 0;
   foreach my $element (@elements) {
     my $id = 'header_' . ${hdr_ct};
@@ -277,7 +276,7 @@ Dancer2::Plugin::MarkdownFilesToHTML
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
